# Generated by Django 2.2.9 on 2019-12-28 07:59

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.utils.timezone
import django_ses_feedback.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='EmailAddressNotification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(default=django.utils.timezone.now)),
                ('modified', models.DateTimeField(default=django.utils.timezone.now)),
                ('email', models.EmailField(max_length=255)),
                ('count', models.PositiveIntegerField(default=0)),
                ('notifications', django.contrib.postgres.fields.jsonb.JSONField(default=django_ses_feedback.models._default_notification_dict)),
            ],
        ),
    ]
