# Generated by Django 3.2 on 2021-05-10 19:17

from django.db import migrations, models
import django_ses_feedback.models


class Migration(migrations.Migration):

    dependencies = [
        ('django_ses_feedback', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailaddressnotification',
            name='notifications',
            field=models.JSONField(default=django_ses_feedback.models._default_notification_dict),
        ),
    ]
